==> aws-sdk-cpp-1.11.667-1-x86_64.pkg.tar.zst: usr/include/aws/neptune-graph/NeptuneGraphEndpointProvider.h <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/neptune-graph/NeptuneGraph_EXPORTS.h>
#include <aws/core/client/GenericClientConfiguration.h>
#include <aws/core/endpoint/DefaultEndpointProvider.h>
#include <aws/core/endpoint/EndpointParameter.h>
#include <aws/core/utils/memory/stl/AWSString.h>
#include <aws/core/utils/memory/stl/AWSVector.h>

#include <aws/neptune-graph/NeptuneGraphEndpointRules.h>


namespace Aws
{
namespace NeptuneGraph
{
namespace Endpoint
{
using EndpointParameters = Aws::Endpoint::EndpointParameters;
using Aws::Endpoint::EndpointProviderBase;
using Aws::Endpoint::DefaultEndpointProvider;

using NeptuneGraphClientContextParameters = Aws::Endpoint::ClientContextParameters;

using NeptuneGraphClientConfiguration = Aws::Client::GenericClientConfiguration;
using NeptuneGraphBuiltInParameters = Aws::Endpoint::BuiltInParameters;

/**
 * The type for the NeptuneGraph Client Endpoint Provider.
 * Inherit from this Base class / "Interface" should you want to provide a custom endpoint provider.
 * The SDK must use service-specific type for each service per specification.
 */
using NeptuneGraphEndpointProviderBase =
    EndpointProviderBase<NeptuneGraphClientConfiguration, NeptuneGraphBuiltInParameters, NeptuneGraphClientContextParameters>;

using NeptuneGraphDefaultEpProviderBase =
    DefaultEndpointProvider<NeptuneGraphClientConfiguration, NeptuneGraphBuiltInParameters, NeptuneGraphClientContextParameters>;

/**
 * Default endpoint provider used for this service
 */
class AWS_NEPTUNEGRAPH_API NeptuneGraphEndpointProvider : public NeptuneGraphDefaultEpProviderBase
{
public:
    using NeptuneGraphResolveEndpointOutcome = Aws::Endpoint::ResolveEndpointOutcome;

    NeptuneGraphEndpointProvider()
      : NeptuneGraphDefaultEpProviderBase(Aws::NeptuneGraph::NeptuneGraphEndpointRules::GetRulesBlob(), Aws::NeptuneGraph::NeptuneGraphEndpointRules::RulesBlobSize)
    {}

    ~NeptuneGraphEndpointProvider()
    {
    }
};
} // namespace Endpoint
} // namespace NeptuneGraph
} // namespace Aws

==> aws-sdk-cpp-1.11.710-1-x86_64.pkg.tar.zst: usr/include/aws/neptune-graph/NeptuneGraphEndpointProvider.h <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/core/client/GenericClientConfiguration.h>
#include <aws/core/endpoint/DefaultEndpointProvider.h>
#include <aws/core/endpoint/EndpointParameter.h>
#include <aws/core/utils/memory/stl/AWSString.h>
#include <aws/core/utils/memory/stl/AWSVector.h>
#include <aws/neptune-graph/NeptuneGraphEndpointRules.h>
#include <aws/neptune-graph/NeptuneGraph_EXPORTS.h>

namespace Aws {
namespace NeptuneGraph {
namespace Endpoint {
using EndpointParameters = Aws::Endpoint::EndpointParameters;
using Aws::Endpoint::DefaultEndpointProvider;
using Aws::Endpoint::EndpointProviderBase;

using NeptuneGraphClientContextParameters = Aws::Endpoint::ClientContextParameters;

using NeptuneGraphClientConfiguration = Aws::Client::GenericClientConfiguration;
using NeptuneGraphBuiltInParameters = Aws::Endpoint::BuiltInParameters;

/**
 * The type for the NeptuneGraph Client Endpoint Provider.
 * Inherit from this Base class / "Interface" should you want to provide a custom endpoint provider.
 * The SDK must use service-specific type for each service per specification.
 */
using NeptuneGraphEndpointProviderBase =
    EndpointProviderBase<NeptuneGraphClientConfiguration, NeptuneGraphBuiltInParameters, NeptuneGraphClientContextParameters>;

using NeptuneGraphDefaultEpProviderBase =
    DefaultEndpointProvider<NeptuneGraphClientConfiguration, NeptuneGraphBuiltInParameters, NeptuneGraphClientContextParameters>;

/**
 * Default endpoint provider used for this service
 */
class AWS_NEPTUNEGRAPH_API NeptuneGraphEndpointProvider : public NeptuneGraphDefaultEpProviderBase {
 public:
  using NeptuneGraphResolveEndpointOutcome = Aws::Endpoint::ResolveEndpointOutcome;

  NeptuneGraphEndpointProvider()
      : NeptuneGraphDefaultEpProviderBase(Aws::NeptuneGraph::NeptuneGraphEndpointRules::GetRulesBlob(),
                                          Aws::NeptuneGraph::NeptuneGraphEndpointRules::RulesBlobSize) {}

  ~NeptuneGraphEndpointProvider() {}
};
}  // namespace Endpoint
}  // namespace NeptuneGraph
}  // namespace Aws
